@@ -7,8 +7,13 @@
 
 set -e
 
+cd ../libzia
+./configure --without-ftdi
+make
+
+cd ../tucnak
 #./configure --without-gpm --without-ftdi --without-hamlib --without-fftw3
-./configure --without-gpm
+./configure --without-gpm --with-pkg=eee
 make
 
 VER=`make ver`
@@ -24,7 +29,7 @@ sed 's/gfx_y *=.*/gfx_y           = 416/' <1 >2
 sed 's/loglines *=.*/loglines        = 1/' <2 >3
 sed 's/cwda_type *=.*/cwda_type     = 0/' <3 >tucnak/tucnakrc
 
-F="tucnak2-eee-$VER.tar.gz"
+F="tucnak3-eee-$VER.tar.gz"
 tar czf ../$F tucnak
 echo $F created
 cd ..
