@@ -1,6 +1,6 @@
 /*
     ac.c - aircraft trace
-    Copyright (C) 2013-2023 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2013-2024 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -75,6 +75,10 @@ struct acs *init_acs(void){
             acs_airdk_init(acs);
             break;
 
+        case AC_DUMP1090:
+            acs_dump1090_init(acs);
+            break;
+
         default:
             log_addf(TRANSLATE("Unknown AS provider"));
             break;
@@ -385,7 +389,7 @@ void plot_ac(struct subwin *sw, struct ac *ac){
     if (undercursor){
         fcolor = z_makecol(21, 193, 106);
         bcolor = z_makecol(15, 150, 70);
-    }else if (ac->id && *ac->id && strcmp(ac->id, gacs->sh.tracked) == 0){
+    }else if (/*ac->id &&*/ *ac->id && strcmp(ac->id, gacs->sh.tracked) == 0){
         fcolor = z_makecol(255, 0, 255);
         bcolor = z_makecol(192, 0, 192);
     }else if (ctp->path_valid == 1 && res->under){
@@ -488,10 +492,10 @@ void plot_info_ac(struct subwin *sw, SDL_Surface *surface, struct ac *ac){
             zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_SPEED4D_KMH), ac->speed); y += FONT_H + 4;
         }
 
-        if (ac->icaotype != NULL && strlen(ac->icaotype) > 0) {
+        if (/*ac->icaotype != NULL &&*/ strlen(ac->icaotype) > 0) {
             zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("Type:  %s")/*VTEXT(T_SPEED4D_KMH)*/, ac->icaotype); y += FONT_H + 4;
         }
-        if (ac->callsign != NULL && strlen(ac->callsign) > 0) {
+        if (/*ac->callsign != NULL &&*/ strlen(ac->callsign) > 0) {
             zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("Call:  %s")/*VTEXT(T_SPEED4D_KMH)*/, ac->callsign); y += FONT_H + 4;
         }
         if (ac->wingspan == 0) {
