@@ -192,13 +192,17 @@ void acs_osn_plot_info(struct subwin* sw, SDL_Rect* area, struct acs* acs) {
         return;
     }
 
-    if (acs->osn_requests_remaining < 0) return; // -1 is no information
+    if (acs->osn_requests_remaining >= 0) { // -1 is no information
 
-    if (acs->osn_requests_remaining >= 40)
-        c = sdl->gr[11];
-    else
-        c = z_makecol(252, 0, 0);
+        if (acs->osn_requests_remaining >= 40)
+            c = sdl->gr[11];
+        else
+            c = z_makecol(252, 0, 0);
+
+        zsdl_printf(surface, area->x + 50, area->y + 5, c, 0, ZFONT_TRANSP | ZFONT_OUTLINE, TRANSLATE("OpenSkyNetwork requests remaining: %d"), acs->osn_requests_remaining);
+    }
+
+    zsdl_printf(surface, area->x + 50, area->y + 5, sdl->gr[12], 0, ZFONT_TRANSP | ZFONT_OUTLINE, "OpenSkyNetwork");
 
-    zsdl_printf(surface, area->x + 50, area->y + 5, c, 0, ZFONT_TRANSP | ZFONT_OUTLINE, TRANSLATE("OpenSkyNetwork requests remaining: %d"), acs->osn_requests_remaining);
 }
 #endif
\ No newline at end of file
