@@ -19,9 +19,19 @@
 #include <android/log.h>
 
 int android_main(int argc, char *argv[]){
-	GString *gs;
 	SDL_version sdl_compiled;
+    
+	GString *gsa = g_string_sized_new(200);
+    int i;
+    for (i = 0; i < argc; i++) {
+        if (i > 0) g_string_append(gsa, ", ");
+        g_string_sprintfa(gsa, "'%s'", argv[i]);
+    }
+    dbg("android_main(%s)\n", gsa->str);
+    g_string_free(gsa, TRUE);
+    
 
+	GString *gs;
 	gs = g_string_new("------ Settings: --------\n");
 	g_string_sprintfa(gs, "   version: %s-%s %s\n", PACKAGE, Z_PLATFORM, VERSION);
 	g_string_sprintfa(gs, "  compiler: gcc %d.%d.%d\n", __GNUC__, __GNUC_MINOR__, __GNUC_PATCHLEVEL__);
@@ -105,15 +115,15 @@ void free_ntpq(struct ntpq *ntpq){
 
 // http://www3.ntu.edu.sg/home/ehchua/programming/java/JavaNativeInterface.html
 static JNIEnv *genv;
-//static jobject gMainActivity;
-//static jclass gMainActivityClass;
+//static jobject gTucnakActivity;
+//static jclass gTucnakActivityClass;
 static jobject gbundle;
 static jmethodID gputString;
 //#static jstring gjstr;
 //static const char *gstr = NULL;
 struct state *gstate = NULL;
 
-JNIEXPORT void JNICALL Java_cz_nagano_tucnak_MainActivity_nativeSetState(JNIEnv *env, jobject thiz, jobject jkey, jobject jval){
+JNIEXPORT void JNICALL Java_cz_nagano_tucnak_TucnakActivity_nativeSetState(JNIEnv *env, jobject thiz, jobject jkey, jobject jval){
     if (!gstate) gstate = init_state();
 
     const char *key = (*env)->GetStringUTFChars(env, jkey, NULL);
@@ -163,8 +173,8 @@ static void android_save_one(gpointer key, gpointer val, gpointer user_data){
 int updating = 0;
 
 
-JNIEXPORT void JNICALL Java_cz_nagano_tucnak_MainActivity_nativeOnSaveInstanceState(JNIEnv *env, jobject thiz, jobject bundle){
-    dbg("Java_cz_nagano_tucnak_MainActivity_nativeOnSaveInstance started bundle=%p genv=%p env=%p\n", bundle, genv, env);
+JNIEXPORT void JNICALL Java_cz_nagano_tucnak_TucnakActivity_nativeOnSaveInstanceState(JNIEnv *env, jobject thiz, jobject bundle){
+    dbg("Java_cz_nagano_tucnak_TucnakActivity_nativeOnSaveInstance started bundle=%p genv=%p env=%p\n", bundle, genv, env);
 	save_all_bands_txt(0); 
     if (updating){
         dbg("updating is active, exiting app\n");
@@ -185,7 +195,7 @@ JNIEXPORT void JNICALL Java_cz_nagano_tucnak_MainActivity_nativeOnSaveInstanceSt
     free_state(state);
     state = NULL;
 
-    dbg("Java_cz_nagano_tucnak_MainActivity_nativeOnSaveInstance finished\n");
+    dbg("Java_cz_nagano_tucnak_TucnakActivity_nativeOnSaveInstance finished\n");
 }
 
 
@@ -196,12 +206,12 @@ void android_update_package(char *filename){
 
 
 
-JNIEXPORT void JNICALL Java_cz_nagano_tucnak_MainActivity_nativeWavPlayed(JNIEnv *env, jobject thiz){
+JNIEXPORT void JNICALL Java_cz_nagano_tucnak_TucnakActivity_nativeWavPlayed(JNIEnv *env, jobject thiz){
     dbg("nativeWavPlayed\n");
 	zselect_msg_send(zsel, "SSBP;%s", "e");
 }
 
-JNIEXPORT void JNICALL Java_cz_nagano_tucnak_MainActivity_nativeWavError(JNIEnv *env, jobject thiz, jobject jstr){
+JNIEXPORT void JNICALL Java_cz_nagano_tucnak_TucnakActivity_nativeWavError(JNIEnv *env, jobject thiz, jobject jstr){
     dbg("nativeWavError...\n");
     const char *str = (*env)->GetStringUTFChars(env, jstr, NULL);
     dbg("nativeWavError('%s')\n", str);
@@ -214,7 +224,7 @@ JNIEXPORT void JNICALL Java_cz_nagano_tucnak_MainActivity_nativeWavError(JNIEnv
 
 
 
-/*JNIEXPORT void JNICALL Java_cz_nagano_tucnak_MainActivity_nativeMsgSend(JNIEnv *env, jobject thiz, jobject jstr){
+/*JNIEXPORT void JNICALL Java_cz_nagano_tucnak_TucnakActivity_nativeMsgSend(JNIEnv *env, jobject thiz, jobject jstr){
     const char *str = (*genv)->GetStringUTFChars(genv, jkey, NULL);
     dbg("nativeMsgSend('%s')\n", str);
     zselect_msg_send(zsel, str);
