@@ -13,7 +13,7 @@
 #include <zconfig.h>
 
 #ifdef Z_HAVE_SDL
-#include "cor.h"
+#include "libzia.h"
 #include "cordata.h"
 #include "cordata.inc"
 #endif
