@@ -365,7 +365,7 @@ static void cwenqueue(struct cwdaemon *cwda){
         break;        
     }
     
-    dbg("enqueue %c '%s'  played='%s'\n", ch, s, cwda->played->str);
+    dbg("enqueue  ch='%c'  s='%s'  played='%s'\n", ch, s, cwda->played->str);
     
     gettimeofday(&tv, NULL);
     i=0;
@@ -407,8 +407,8 @@ static void cwenqueue(struct cwdaemon *cwda){
             i++;
         }
         if (*c=='\0'){
-            cwqueue[i].tv.tv_sec=tv.tv_sec;       
-            cwqueue[i].tv.tv_usec=tv.tv_usec;       
+            cwqueue[i].tv.tv_sec=tv.tv_sec;
+            cwqueue[i].tv.tv_usec=tv.tv_usec;
             cwqueue[i].on=2;
             cwqueue[i].last=0;
             cwqueue[i].ch='0';
@@ -423,7 +423,7 @@ static void cwenqueue(struct cwdaemon *cwda){
             cwqueue[i].on=0;
             cwqueue[i].last=0;
             cwqueue[i].ch='_';
-            tv.tv_usec+=(5 * 24000 * cwda->weight) / cwda->speed;
+            tv.tv_usec+=(2 * 24000 * cwda->weight) / cwda->speed; // 7 - 1 - 2 - 2 = 2
             while (tv.tv_usec>=1000000) {tv.tv_usec-=1000000;tv.tv_sec++; }
             i++;
         }
@@ -468,6 +468,8 @@ gpointer cwdaemon_thread_func(gpointer data){
     int ret, i;
     char buf[1030];
     struct cwdaemon *cwda;
+    int oldon = 0;
+    int oldms = ztimeout_init(0);
 
     cwda=(struct cwdaemon*)data;
 	zg_thread_set_name("Tucnak cwdaemon");
@@ -490,7 +492,7 @@ gpointer cwdaemon_thread_func(gpointer data){
             while(interval.tv_usec<0) { interval.tv_usec+=1000000; interval.tv_sec--; }
             if (interval.tv_sec<0) {interval.tv_sec=0;interval.tv_usec=0;}
             tv=&interval;
-            /*dbg("select(%2d.%06d)\n", interval.tv_sec%100, interval.tv_usec); */
+            //dbg("select(%2d.%06d)  on=%d\n", interval.tv_sec%100, interval.tv_usec, cwqueue[qi].on);
         }
         
         ret=select(cwda->pipe_read+1, &rd, NULL, NULL, tv);
@@ -575,7 +577,9 @@ check_queue:
             if (cwqueue[qi].tv.tv_usec>now.tv_usec) continue;
         }
 		
-        //dbg("playing %d %c\n", qi, cwqueue[qi].ch);
+        dbg("playing  qi=%d  on=%d  %dms\n", qi, oldon, ztimeout_diff_ms(&oldms));
+        oldms = ztimeout_init(0);
+        oldon = cwqueue[qi].on;
 
         if (cwqueue[qi].on==1){
             if (cwda->cw) cwda->cw(cwda, 1);
@@ -601,7 +605,7 @@ void cwdaemon_read_handler(struct cwdaemon *cwda, char *s, char *played){
         gses->last_cq_timer_id = 0;
     }
 
-    dbg("cwdaemon_read_handler   rcvd: '%s'  played='%s'\n", s, played);
+    //dbg("cwdaemon_read_handler   rcvd: '%s'  played='%s'\n", s, played);
     switch(s[0]){
         case '!':  /* error */
             cq_abort(SSBDRECORDING); /*abort recording only if it is in progress */
