@@ -145,6 +145,10 @@ struct dsp *init_dsp(enum dsp_type type, enum dsp_cfg_group dcg){
 				case DCG_SSBD:
 					dsp->pa_play = cfg->ssbd_pa_play;
 					dsp->pa_rec = cfg->ssbd_pa_rec;
+                    dsp->pa_play_hi = cfg->ssbd_pa_play_hi;
+                    dsp->pa_rec_hi = cfg->ssbd_pa_rec_hi;
+                    dsp->pa_play_s = g_strdup(cfg->ssbd_pa_play_s);
+                    dsp->pa_rec_s = g_strdup(cfg->ssbd_pa_rec_s);
 					break;
 				case DCG_SDR:
 					dsp->pa_play = cfg->sdr_pa_play;
@@ -281,6 +285,8 @@ void free_dsp(struct dsp *dsp){
 		//Pa_Terminate();
 		//pa_initialised = 0;
 	}
+    zg_free0(dsp->pa_play_s);
+    zg_free0(dsp->pa_rec_s);
 #endif
 #ifdef HAVE_SNDFILE
 	if (dsp->sndfile) sf_close(dsp->sndfile);
