@@ -288,7 +288,7 @@ typedef long long vint;
 #include <zsun.h>
 
 #define VERSION_STRING          VERSION
-#define AUTOSAVE 
+#undef AUTOSAVE 
 
 #define DEBUG
 
