@@ -650,6 +650,7 @@ void sw_kst_addrinfo(struct zasyncdns *adns, int n, int *family, int *socktype,
         //dbg("socket(%d, %d, %d)\n", family[i], socktype[i], protocol[i]);
         //sw->sock = socket(family[i], socktype[i], protocol[i]);
         sw->sock = socket(family[i], SOCK_STREAM, 0);
+        int err = z_sock_errno;
         if (sw->sock < 0) {
             sw_printf(sw, VTEXT(T_CANT_CREATE_SOCKET), z_sock_strerror());
             continue;
@@ -711,14 +712,14 @@ void sw_kst_connected_handler(void *xxx){
 
 void sw_kst_read_handler(void *xxx){
     char buf[1030], *d, *last, errbuf[100];
-    int i, ret, e;
+    int i, ret;
     struct subwin *sw = (struct subwin *)xxx;
 
     ret = recv(sw->sock, buf, 1024, 0);
-    e = errno;
+    int err = z_sock_errno;
     if (ret <= 0){
         if (z_sock_errno != 0){ // zero is handled by sw_kst_disconnect()
-            sw_printf(sw, VTEXT(T_ERROR_READING_SOCKET), z_sock_strerror(), sw->sock, e);
+            sw_printf(sw, VTEXT(T_ERROR_READING_SOCKET), z_sock_strerror());
         }
         sw_kst_disconnect(sw);
         return;
