@@ -290,9 +290,15 @@ static void init_home(void)
 		home_dir = g_strdup(c);
 		z_dirname(home_dir);
 	}
+    dbg("tucnak_dir=%s  opt_home_dir=%s\n", tucnak_dir, opt_home_dir);
+	if (!tucnak_dir && opt_home_dir != NULL){
+		home_dir = g_strdup(opt_home_dir);
+        dbg("home_dir=%s\n", home_dir);
+		if (home_dir) tucnak_dir = g_strdup_printf("%s/tucnak", home_dir);
+        dbg("tucnak_dir=%s\n", tucnak_dir);
+	}
 	if (!tucnak_dir){
 		home_dir = g_strdup(getenv("HOME"));
-		//home_dir = NULL;//FIXME
 		if (home_dir) tucnak_dir = g_strdup_printf("%s/tucnak", home_dir);
 	}
 #ifdef Z_MSC_MINGW 
@@ -313,10 +319,11 @@ static void init_home(void)
 	z_wokna(home_dir);
 	
     if (stat(tucnak_dir, &st)) {
-        if (z_mkdir(tucnak_dir, 0777)) zinternal(VTEXT(T_CANT_CREATE_HOME), tucnak_dir);
+        // NO VTEXT!
+        if (z_mkdir(tucnak_dir, 0777)) zinternal("Can't create home directory '%s'", tucnak_dir);
     }else{
     // exists  
-        if (!S_ISDIR(st.st_mode)) zinternal(VTEXT(T_MUST_BE_DIR_MODE), tucnak_dir, st.st_mode);
+        if (!S_ISDIR(st.st_mode)) zinternal("'%s' must be directory (mode 0%oo)", tucnak_dir, st.st_mode);
 	}
 }
 
@@ -478,7 +485,6 @@ void info(GString *gs){
 #ifdef Z_ANDROID
     double h, w;
     int state;
-    //SDL_ANDROID_GetHW(&h, &w, &state);
     zandroid_init(zsel);
     zandroid_get_location(&h, &w, &state);
     g_string_append_printf(gs, "\n  geolocation info\n");
@@ -487,7 +493,7 @@ void info(GString *gs){
         case 0: g_string_append(gs, "searching\n"); break;
         case 1: g_string_append(gs, "fixed\n"); break;
         case 2: g_string_append(gs, "error\n"); break;
-        default: g_string_append_printf(gs, "unknown\n", state); break;
+        default: g_string_append_printf(gs, "unknown\n"); break;
     }
     if (h > -1000 && h < 1000){
 	    g_string_append_printf(gs, "lon: %f\n", h);
@@ -634,13 +640,12 @@ static void init(void)
 #ifndef Z_MSC_MINGW
     zselect_signal_set(SIGCHLD, sigchld, NULL, 1);
 #endif
-
     init_home();
 	
     init_keymaps();
 	read_rc_files();
 #ifdef Z_ANDROID
-    SDL_Android_key_trace(android_trace_keys);
+    //SDL_Android_key_trace(android_trace_keys);
 #endif
 	
 	set_logs_dir();
@@ -866,7 +871,9 @@ static void terminate_all_subsystems(void)
 
 void redraw(void){
     
- //   dbg("redraw()\n");
+    //dbg("redraw()  paused=%d\n", sdl->paused);
+    if (sdl->paused) return;
+
 #ifdef Z_HAVE_SDL        
     if (sdl) {
         sdl_redraw_screen();
@@ -1180,6 +1187,9 @@ int main(int argc, char *argv[])
 #endif
 
     zsel = zselect_init(redraw);
+#ifdef Z_ANDROID
+    zandroid_init(zsel);
+#endif    
 	zselect_msg_set(zsel, main_msg_handler);
 	//zselect_start_profile(zsel, 0.099);
 	init();
