@@ -382,7 +382,7 @@ void sw_map_redraw_rect(struct subwin *sw, SDL_Rect *area, struct band *band, in
 //    sw_map_update_rotar(sw, area);
 //  dbg("                    %dx%d%+d%+d\n", area->x, area->y, area->w, area->h);
   
-    sw_map_redraw_rotar(sw, area, flags);
+    sw_map_redraw_rotar(sw, area, flags); // blits l1map -> screen
 	if (band && band->tmplocqso.locator && *band->tmplocqso.locator){
 		plot_qso(sw, sw->screen, band, &band->tmplocqso);
 		if (gacs) plot_path(sw, sw->screen, band, &band->tmplocqso, &gacs->tmpqso);
