@@ -59,7 +59,24 @@
 
 #include "misc.h"
 
-void menu_about(void *arg)
+
+void menu_support_paypal(void) {
+    z_browser("https://www.paypal.com/donate?hosted_button_id=M295RS22XFZPJ");
+}
+
+void menu_support_buymeacoffee(void) {
+    z_browser("https://www.buymeacoffee.com/ok1zia");
+}
+
+void menu_support_tucnak(void *arg)
+{
+    msg_box(NULL, TRANSLATE("Support Tucnak"), AL_CENTER, TRANSLATE("How do you want to support Tucnak development?"), NULL, 3, 
+        TRANSLATE("PayPal"), menu_support_paypal, B_ENTER,
+        TRANSLATE("buymeacoffee.com"), menu_support_buymeacoffee, 0,
+        VTEXT(T_CANCEL), NULL, B_ESC);
+}
+
+void menu_about(void* arg)
 {
     msg_box(NULL, VTEXT(T_ABOUT), AL_CENTER, VTEXT(T_TUCNAK__TACLOG_LIKE), NULL, 1, VTEXT(T_OK), NULL, B_ENTER | B_ESC);
 }
@@ -954,6 +971,8 @@ void menu_confirm_phase(void *xxx, char *phase){
 	char s[100];
 	g_snprintf(s, 100, "PH %d\n", ph);
 	rel_write_all(s);
+
+    qrv_recalc_wkd(qrv);
 }
 
 
@@ -1137,7 +1156,7 @@ static struct menu_item file_menu22[] = {
     {CTEXT(T_NINFO), "", CTEXT(T_HK_NINFO), MENU_FUNC net_info, NULL, 0, 0},
 //	{CTEXT(T_CRASH_TEST), "", CTEXT(T_HK_CRASH_TEST), crash_test, NULL, 0, 0},
 //	{CTEXT(T_INTERROR_TEST), "", CTEXT(T_HK_INTERNAL_TEST), internal_test, NULL, 0, 0},
-	{CTEXT(T_DUMP_RW_BANDS), "", CTEXT(T_HK_DUMP_RW_BANDS), dump_rw, NULL, 0, 0},
+	//{CTEXT(T_DUMP_RW_BANDS), "", CTEXT(T_HK_DUMP_RW_BANDS), dump_rw, NULL, 0, 0},
 	{CTEXT(T_UPDATE), "", CTEXT(T_HK_UPDATE), update_tucnak, NULL, 0, 0},
     {"", "", M_BAR, NULL, NULL, 0, 0}
 };
@@ -1199,6 +1218,7 @@ void do_file_menu(void *arg)
 
 
 static struct menu_item help_menu[] = {
+    {TRANSLATE("Support Tucnak"), "", CTEXT(T_HK_ABOUT), MENU_FUNC menu_support_tucnak, NULL, 0, 0},
     {CTEXT(T_ABOUT), "", CTEXT(T_HK_ABOUT), MENU_FUNC menu_about, NULL, 0, 0},
     {CTEXT(T_COPYING), "", CTEXT(T_HK_COPYING), MENU_FUNC menu_copying, NULL, 0, 0},
     {CTEXT(T_VERSION), "", CTEXT(T_HK_VERSION), MENU_FUNC menu_version, NULL, 0, 0},
@@ -1726,9 +1746,7 @@ static struct menu_item setup_menu[] = {
     {CTEXT(T_MISCOPTS), "", CTEXT(T_HK_MISCOPTS), MENU_FUNC misc_opts, NULL, 0, 0},
     //{CTEXT(T_TERMINAL_OPTIONS), "", CTEXT(T_HK_TERMINAL_OPTIONS), MENU_FUNC terminal_options, NULL, 0, 0},
     {CTEXT(T_HTTPD_OPTIONS)/*CTEXT(T_TERMINAL_OPTIONS)*/, "", CTEXT(T_HK_HTTP_OPTIONS)/*CTEXT(T_HK_TERMINAL_OPTIONS)*/, MENU_FUNC menu_httpd_opts, NULL, 0, 0},
-#ifndef Z_ANDROID
     {CTEXT(T_AC_OPTIONS)/*CTEXT(T_TERMINAL_OPTIONS)*/, "", CTEXT(T_HK_AC_OPTIONS)/*CTEXT(T_HK_TERMINAL_OPTIONS)*/, MENU_FUNC menu_ac_opts, NULL, 0, 0},
-#endif
 #if defined(HAVE_ALSA) || defined (HAVE_PORTAUDIO)
     {CTEXT(T_SDR_OPTIONS)/*CTEXT(T_TERMINAL_OPTIONS)*/, "", CTEXT(T_HK_SDR_OPTIONS)/*CTEXT(T_HK_TERMINAL_OPTIONS)*/, MENU_FUNC menu_sdr_opts, NULL, 0, 0},
 #endif
