@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2011-2022 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2023 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -161,8 +161,7 @@ void menu_cw_update_contest(void *arg);
 void menu_cw_update_band(void *arg);
 void menu_exc_update_contest(void *arg);
 void menu_exc_update_band(void *arg);
-void menu_import_ebw(void *arg);
-void menu_autosave(void *arg);
+void menu_import_mmm(void *arg);
 void menu_add_subwin(void *arg);
 void menu_close_subwin(void *arg);
 void menu_split_subwin(void *arg);
@@ -198,6 +197,12 @@ void menu_sdr_opts(void *arg);
 
 /* menu7.c */
 void menu_rain_opts(void *itdata, void *menudata);
+#ifdef OCT8TOR
+void menu_oct8tor_opts(void *itdata, void *menudata);
+#endif
 
+#ifdef HAVE_HIDAPI
+int dlg_davac5_opts(struct dialog_data *dd, struct dialog_item_data *did);
+#endif
 
 #endif
