@@ -399,19 +399,19 @@ void band_settings(void *arg, int from_ctest)
     	d->items[i].wrap = 1;
 
         d->items[++i].type = D_FIELD;
-        d->items[i].dlen = 10;
+        d->items[i].dlen = 11;
         d->items[i].data = qrg_min_str;
         d->items[i].fn   = check_number;
         d->items[i].gid  = 0;
-        d->items[i].gnum = 250000000;
+        d->items[i].gnum = 2000000000;
         d->items[i].msg = CTEXT(T_QRG_MIN);
 
         d->items[++i].type = D_FIELD;
-        d->items[i].dlen = 10;
+        d->items[i].dlen = 11;
         d->items[i].data = qrg_max_str;
         d->items[i].fn   = check_number;
         d->items[i].gid  = 0;
-        d->items[i].gnum = 250000000;
+        d->items[i].gnum = 2000000000;
 		d->items[i].msg = CTEXT(T_QRG_MAX);
     	d->items[i].wrap = 1;
 
@@ -1276,7 +1276,6 @@ void contest_options1(char *title, int from_ctest, struct wizz_item *wi)
     if (!from_ctest){
         double h, w;
         int state;
-        //SDL_ANDROID_GetHW(&h, &w, &state);
         zandroid_get_location(&h, &w, &state);
         //log_addf("contest_options1: h=%f w=%f\n", h, w);
         if (h > -1000 && h < 1000){ // todo v zavislosti na state
@@ -1838,11 +1837,11 @@ void contest_def(void *pfirst)
 #ifdef Z_ANDROID
     if (first){
         double h, w;
-        SDL_ANDROID_GetHW(&h, &w);
+        /*FIXME SDL_ANDROID_GetHW(&h, &w);
         log_addf("contest_def: h=%f w=%f\n", h, w);
         if (h > -1000 && h < 1000){
             hw2loc(pwwlo, h, w, 6);
-        }
+        }*/
     }else
 #endif
     {
