@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2023  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 #include "bfu.h"
 #include "control.h"
 #include "cwdb.h"
-#include "ebw.h"
+#include "mmm.h"
 #include "edi.h"
 #include "excdb.h"
 #include "fifo.h"
@@ -237,7 +237,9 @@ void refresh_chop(void *xxx){
     }
     
     redraw_later();
-    
+#ifdef AUTOSAVE
+    menu_save_rc(NULL);
+#endif
 }
 
 void chop_fn(struct dialog_data *dlg)
@@ -345,6 +347,8 @@ void do_skedqrg(struct session *ses, char *qrg){
     c = g_strdup_printf("RG %s;%s\n",aband->pband,qrg);
     rel_write_all(c);
     g_free(c);  
+ 
+    save_all_bands_txt(0);
     redraw_later();
 }
 
@@ -512,230 +516,36 @@ void menu_exc_update_band(void *arg){
     g_free(s);
 }
 
-void menu_import_ebw(void *arg){
-    int ret;
-    
-    ret=read_ebw_files(cw, namedb);
-	if (ret!=0) return;
-    
-	save_cw(cw, 1);
-    save_namedb(namedb, 1);
+static void import_mmm(void *xxx, char *filename){
+    int nlocs = 0, nnames = 0;
+	int ret = load_mmm_from_file(cw, namedb, filename, &nlocs, &nnames);
+	if (ret == 0){
+		log_addf(TRANSLATE("Loaded %d locs and %d names"), nlocs, nnames);
+		save_cw(cw, 1);
+		save_namedb(namedb, 1);
+	}
+	else{
+		log_addf(VTEXT(T_ERROR_D), ret);
+	}
 }
 
-/******************** AUTOSAVE *******************************/
+void menu_import_mmm(void *arg){
+	
+    if (
+#ifdef Z_HAVE_SDL
+		!sdl ||
+#endif                    
+		zfiledlg_open(zfiledlg, zsel, import_mmm, NULL, "", "txt") < 0){
+		input_field(NULL, VTEXT(T_IMPORT_EDI), VTEXT(T_FILENAME),
+			VTEXT(T_OK), VTEXT(T_CANCEL), gses,
+			NULL, 150, NULL, 0, 0, NULL,
+			import_mmm, NULL, 1);
+	}
 
-#define AS_LEN 5
-
-/*char as_disk_aq_str[AS_LEN], as_disk_am_str[AS_LEN];
-gint as_disk_fsync;*/
-char as_floppy_aq_str[AS_LEN], as_floppy_am_str[AS_LEN];
-gint as_floppy_fsync;
-gint as_mount;
-char as_floppy_path[MAX_STR_LEN];
-char as_mount_cmd[MAX_STR_LEN];
-
-                                                   
-void refresh_autosave(void *xxx)
-{
-/*    STORE_SINT(cfg,as_disk_aq);
-    STORE_SINT(cfg,as_disk_am);
-    STORE_INT (cfg,as_disk_fsync); */
-    STORE_SINT(cfg,as_floppy_aq);
-    STORE_SINT(cfg,as_floppy_am);
-    STORE_INT (cfg,as_floppy_fsync);
-    STORE_INT (cfg,as_mount);
-    STORE_STR(cfg,as_floppy_path);
-    STORE_STR(cfg,as_mount_cmd);
-
-    dbg("refresh_autosave\n");
 }
 
-char *autosave_msg[] = {
-#if 0
-    CTEXT(T_SAVE_AQ), /* 0 */
-    CTEXT(T_SAVE_AM),
-    CTEXT(T_FSYNC),
-#endif    
-    CTEXT(T_SAVE_AQF), /* 0 */
-    CTEXT(T_SAVE_AMF),
-    CTEXT(T_FSYNC),                 
-    
-    CTEXT(T_DO_MOUNT),
-    CTEXT(T_FLOPPY_PATH),     /* 5 */
-    CTEXT(T_MOUNT_CMD), 
-    "", /* OK */  /* 9 */
-    "", /* Cancel */
-};
 
-void autosave_fn(struct dialog_data *dlg)
-{
-    struct terminal *term = dlg->win->term;
-    int max = 0, min = 0;
-    int w, rw;
-    int y = -1;
 
-    max_group_width(term, autosave_msg + 0, dlg->items + 0, 1, &max);
-    min_group_width(term, autosave_msg + 0, dlg->items + 0, 1, &min);
-    max_group_width(term, autosave_msg + 1, dlg->items + 1, 1, &max);
-    min_group_width(term, autosave_msg + 1, dlg->items + 1, 1, &min);
-    max_group_width(term, autosave_msg + 2, dlg->items + 2, 1, &max);
-    min_group_width(term, autosave_msg + 2, dlg->items + 2, 1, &min);
-    max_group_width(term, autosave_msg + 3, dlg->items + 3, 1, &max);
-    min_group_width(term, autosave_msg + 3, dlg->items + 3, 1, &min);
-    max_group_width(term, autosave_msg + 4, dlg->items + 4, 1, &max);
-    min_group_width(term, autosave_msg + 4, dlg->items + 4, 1, &min);
-    max_group_width(term, autosave_msg + 5, dlg->items + 5, 1, &max);
-    min_group_width(term, autosave_msg + 5, dlg->items + 5, 1, &min);
- /*   max_group_width(term, autosave_msg + 6, dlg->items + 6, 1, &max);
-    min_group_width(term, autosave_msg + 6, dlg->items + 6, 1, &min);
-    max_group_width(term, autosave_msg + 7, dlg->items + 7, 1, &max);
-    min_group_width(term, autosave_msg + 7, dlg->items + 7, 1, &min);
-    max_group_width(term, autosave_msg + 8, dlg->items + 8, 1, &max);
-    min_group_width(term, autosave_msg + 8, dlg->items + 8, 1, &min);
- */   
-    max_buttons_width(term, dlg->items + 6, 2, &max);
-    min_buttons_width(term, dlg->items + 6, 2, &min);
-    
-    w = dlg->win->term->x * 9 / 10 - 2 * DIALOG_LB;
-    if (w > max) w = max;
-    if (w < min) w = min;
-    if (w > dlg->win->term->x - 2 * DIALOG_LB - 8 ) w = dlg->win->term->x - 2 * DIALOG_LB - 8;
-    if (w < 1) w = 1;
-    
-    rw = 0;
-    y ++;
-    dlg_format_group(NULL, term, autosave_msg + 0, dlg->items + 0, 1, 0, &y, w, &rw);
-    dlg_format_group(NULL, term, autosave_msg + 1, dlg->items + 1, 1, 0, &y, w, &rw);
-    dlg_format_group(NULL, term, autosave_msg + 2, dlg->items + 2, 1, 0, &y, w, &rw);
-    y++;
-    dlg_format_group(NULL, term, autosave_msg + 3, dlg->items + 3, 1, 0, &y, w, &rw);
-    dlg_format_group(NULL, term, autosave_msg + 4, dlg->items + 4, 1, 0, &y, w, &rw);
-    dlg_format_group(NULL, term, autosave_msg + 5, dlg->items + 5, 1, 0, &y, w, &rw);
-/*    y++;
-    dlg_format_group(NULL, term, autosave_msg + 6, dlg->items + 6, 1, 0, &y, w, &rw);
-    dlg_format_group(NULL, term, autosave_msg + 7, dlg->items + 7, 1, 0, &y, w, &rw);
-    dlg_format_group(NULL, term, autosave_msg + 8, dlg->items + 8, 1, 0, &y, w, &rw);
-    */
-    y++;
-    dlg_format_buttons(NULL, term, dlg->items + 6, 2, 0, &y, w, &rw, AL_LEFT);
-    
-    
-    w = rw;
-    dlg->xw = w + 2 * DIALOG_LB;
-    dlg->yw = y + 2 * DIALOG_TB;
-
-    
-    center_dlg(dlg);
-    draw_dlg(dlg);
-    y = dlg->y + DIALOG_TB;
-    y++;
-    dlg_format_group(term, term, autosave_msg + 0, dlg->items + 0, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    dlg_format_group(term, term, autosave_msg + 1, dlg->items + 1, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    dlg_format_group(term, term, autosave_msg + 2, dlg->items + 2, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    y++;
-    dlg_format_group(term, term, autosave_msg + 3, dlg->items + 3, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    dlg_format_group(term, term, autosave_msg + 4, dlg->items + 4, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    dlg_format_group(term, term, autosave_msg + 5, dlg->items + 5, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-/*    y++;
-    dlg_format_group(term, term, autosave_msg + 6, dlg->items + 6, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    dlg_format_group(term, term, autosave_msg + 7, dlg->items + 7, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    dlg_format_group(term, term, autosave_msg + 8, dlg->items + 8, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    */
-    y++;
-    dlg_format_buttons(term, term, dlg->items + 6, 2, dlg->x + DIALOG_LB, &y, w, NULL, AL_LEFT);
-    
-}
-
-void menu_autosave(void *arg)
-{
-    struct dialog *d;
-    int i;
-
-    dbg("menu_autosave\n");
- /*   snprint(as_disk_aq_str,AS_LEN, cfg->as_disk_aq);
-    snprint(as_disk_am_str, AS_LEN, cfg->as_disk_am);
-    as_disk_fsync = cfg->as_disk_fsync;*/
-    g_snprintf(as_floppy_aq_str, AS_LEN, "%d", cfg->as_floppy_aq);
-    g_snprintf(as_floppy_am_str, AS_LEN, "%d", cfg->as_floppy_am);
-    as_floppy_fsync = cfg->as_floppy_fsync;
-    as_mount = cfg->as_mount;
-    safe_strncpy0(as_floppy_path, cfg->as_floppy_path, MAX_STR_LEN); 
-    safe_strncpy0(as_mount_cmd, cfg->as_mount_cmd, MAX_STR_LEN); 
-    
-
-    if (!(d = (struct dialog *)g_malloc(sizeof(struct dialog) + 55 * sizeof(struct dialog_item)))) return;
-    memset(d, 0, sizeof(struct dialog) + 55 * sizeof(struct dialog_item));
-    d->title = VTEXT(T_AUTOSAVE_OPTS);
-    d->fn = autosave_fn;
-    d->refresh = (void (*)(void *))refresh_autosave;
-
-    
-/*    d->items[i=0].type = D_FIELD;
-    d->items[i].dlen = AS_LEN;
-    d->items[i].data = as_disk_aq_str;
-    
-    d->items[++i].type = D_FIELD;
-    d->items[i].dlen = AS_LEN;
-    d->items[i].data = as_disk_am_str;
-    
-    d->items[++i].type = D_CHECKBOX;
-    d->items[i].gid = 0;
-    d->items[i].gnum = 1;
-    d->items[i].dlen = sizeof(int);
-    d->items[i].data = (void *)&as_disk_fsync;
-    
-  */  
-    d->items[i=0].type = D_FIELD;
-    d->items[i].dlen = AS_LEN;
-    d->items[i].data = as_floppy_aq_str;
-    d->items[i].fn   = check_number;
-    d->items[i].gid  = 0;
-    d->items[i].gnum = 10000;
-    
-    d->items[++i].type = D_FIELD;
-    d->items[i].dlen = AS_LEN;
-    d->items[i].data = as_floppy_am_str;
-    d->items[i].fn   = check_number;
-    d->items[i].gid  = 0;
-    d->items[i].gnum = 10000;
-    
-    d->items[++i].type = D_CHECKBOX;
-    d->items[i].gid = 0;
-    d->items[i].gnum = 1;
-    d->items[i].dlen = sizeof(int);
-    d->items[i].data = (char *)&as_floppy_fsync;
-    
-
-    d->items[++i].type = D_CHECKBOX;
-    d->items[i].gid = 0;
-    d->items[i].gnum = 1;
-    d->items[i].dlen = sizeof(int);
-    d->items[i].data = (char *)&as_mount;
-    
-    d->items[++i].type = D_FIELD;
-    d->items[i].dlen = MAX_STR_LEN;
-    d->items[i].data = as_floppy_path;
-    d->items[i].maxl = 20;
-    
-    d->items[++i].type = D_FIELD;
-    d->items[i].dlen = MAX_STR_LEN;
-    d->items[i].data = as_mount_cmd;
-    d->items[i].maxl = 20;
-    
-    
-    d->items[++i].type = D_BUTTON;
-    d->items[i].gid = B_ENTER;
-    d->items[i].fn = ok_dialog;
-    d->items[i].text = VTEXT(T_OK);
-    
-    d->items[++i].type = D_BUTTON;
-    d->items[i].gid = B_ESC;
-    d->items[i].fn = cancel_dialog;
-    d->items[i].text = VTEXT(T_CANCEL);
-    
-    d->items[++i].type = D_END;
-    do_dialog(d, getml(d, NULL));
-}
 
 
 /******************** ADD SUBWIN *******************************/
@@ -775,7 +585,9 @@ void refresh_add_sw(void *arg){
 		
 	}
 	if (asw) free_subwin(asw);
-    
+#ifdef AUTOSAVE
+    menu_save_rc(NULL);
+#endif
 }
 
 
@@ -788,6 +600,11 @@ void menu_add_subwin(void *arg){
 	if (!change){
 		asw_type = SWT_SHELL;
 	}
+	else{
+		if (gses->ontop != NULL){
+			asw_type = gses->ontop->type;
+		}
+	}
     safe_strncpy0(asw_cmd, "/bin/sh", MAX_STR_LEN);
     g_snprintf(asw_respawn_str, MAX_STR_LEN, "%d", 10);
     
@@ -991,7 +808,9 @@ void menu_close_subwin(void *arg){
 		sw_totop_next(0, 1);
     sw_totop_next(0, 0);
     redraw_later();
-    
+#ifdef AUTOSAVE
+    menu_save_rc(NULL);
+#endif
 }
 
 /********************* SPLIT SUBWIN ***********************/
