@@ -50,7 +50,7 @@ char *mode_msg[]={
     CTEXT(T_CWS_SSBR),
     CTEXT(T_AM),
     CTEXT(T_FM),
-    CTEXT(T_RTTY),
+    CTEXT(T_MGM),
     CTEXT(T_SSTV),
     CTEXT(T_ATV)   /* 9 */
 };
@@ -389,7 +389,10 @@ struct band *init_band(struct config_band *confb, GHashTable *opt_band, struct z
             b->operator_ = fixsemi(g_strdup(z_get_raw_call(s,ctest->pcall)));
         }
         tmpconfb=get_config_band_by_pband(b->pband);
-        if (tmpconfb) b->readonly = tmpconfb->readonly;
+        if (tmpconfb) {
+            b->readonly = tmpconfb->readonly;
+            b->band_sw = tmpconfb->band_sw;
+        }
     }
 
     
@@ -592,7 +595,7 @@ void default_rst_to_tmpqsos(struct band *b){
 
     /*if (!ctest->qsoused) return;*/
     
-    if (gses->mode == MOD_CW_CW)
+    if (gses->mode == MOD_CW_CW || gses->mode == MOD_ATV_ATV)
         c=g_strdup(cfg->default_rst);
     else
         c=g_strdup(cfg->default_rs);
@@ -1518,8 +1521,8 @@ void set_mode(enum modes mode){
 			case MOD_FM_FM:
 				trig_set_mode_qrg(trig, RIG_MODE_FM, gtrigs->qrg);
 				break;
-			case MOD_RTTY_RTTY:
-				trig_set_mode_qrg(trig, RIG_MODE_RTTY, gtrigs->qrg);
+			case MOD_MGM_MGM:
+				trig_set_mode_qrg(trig, RIG_MODE_NONE, gtrigs->qrg); 
 				break;
 			case MOD_SSTV_SSTV:
 				trig_set_mode_qrg(trig, RIG_MODE_USB, gtrigs->qrg); // SSTV uses SSB
