@@ -352,7 +352,7 @@ struct contest {
     gint  rstused;          /* no,used, optional */
     gint  defrstr;          
     gint  qsoused;          /* no,used, optional */
-    gint  wwlused;          /* no,used, optional */
+    gint  wwlused;          /* 0=no, 1=used(6), 2=optional(6), 3=used(4), 4=optional(4) */
     gint  wwltype;          /* short,normal,extended */
     gint  wwlcfm;
     gint  excused;          /* no,used, optional */
