@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2023  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -11,7 +11,6 @@
 #include "header.h"         
 #include "bfu.h"
 #include "fifo.h"
-#include "hdkeyb.h"
 #include "kbd.h"
 #include "main.h"
 #include "map.h"
@@ -23,6 +22,7 @@
 #include "session.h"
 #include "subwin.h"
 #include "zstring.h"
+#include "oct8tor.h"
 
 
 struct rotar *rota,*rotb;
@@ -31,7 +31,9 @@ struct rotar *rota,*rotb;
 GPtrArray *rotars;
 MUTEX_DEFINE(rotars);
 
-struct rotar *rotar;
+struct rotar *rotar = NULL;
+struct oct8tor *goct8tor;
+
 
 #ifdef HAVE_HAMLIB
 static int rot_print_model_list(const struct rot_caps *caps, void *data)
@@ -44,17 +46,17 @@ static int rot_print_model_list(const struct rot_caps *caps, void *data)
 
 struct rotar *init_rotar(struct config_rotar *crot, int rotchar){
     struct rotar *rot;
-
     if (!crot) return NULL;
     if (!crot->rot_type) return NULL;
 
-    rot = g_new0(struct rotar, 1);
+	rot = g_new0(struct rotar, 1);
 	rot->poll_ms = crot->rot_poll_ms;
 	rot->last_req = ztimeout_init(rot->poll_ms);
+    rot->main_thread = g_thread_self();
 #ifdef HAVE_HAMLIB
 	rot->rot_speed = crot->rot_speed;
 #endif
-    switch(crot->rot_type){
+	switch (crot->rot_type){
         case ROT_OK1ZIA_TTYS:
             rot->sdev=sd_open_ttys(crot->rot_saddr, crot->rot_filename, crot->rot_timeout_ms);
             dbg("init_rotar rot=%p  saddr=%d filename='%s' timeout=%d\n", rot->sdev, crot->rot_saddr, crot->rot_filename, crot->rot_timeout_ms);
@@ -80,11 +82,13 @@ struct rotar *init_rotar(struct config_rotar *crot, int rotchar){
             break;
 #ifdef HAVE_HAMLIB
         case ROT_HAMLIB:
-			if (strlen(crot->rot_filename) == 0){
-				log_addf("Can't init rotator, empty file name");
-				g_free(rot);
-				return NULL;
-			}
+            if (crot->rot_model != 1) {
+                if (strlen(crot->rot_filename) == 0) {
+                    log_addf("Can't init rotator, empty file name");
+                    g_free(rot);
+                    return NULL;
+                }
+            }
             rot->rot = rot_init(crot->rot_model);
 			if (!rot->rot){
 				log_addf(VTEXT(T_UNKNOWN_ROTNR_OR_INIT_ERROR), crot->rot_model);
@@ -124,8 +128,15 @@ struct rotar *init_rotar(struct config_rotar *crot, int rotchar){
 				log_addf(VTEXT(T_CANT_CREATE_HL_ROT_THR));
 			}
             break;
-#endif            
-        default:
+#endif         
+#ifdef OCT8TOR
+		case ROT_OCT8TOR:
+			rot->oct_azim = -1;
+			rot->oct_elev = -90;
+			rot->oct_hidden = true;
+			break;
+#endif
+		default:
             log_addf(VTEXT(T_UNSUPPORTED_ROTATOR), crot->rot_type);
             g_free(rot);
             return NULL;
@@ -158,7 +169,7 @@ struct rotar *init_rotar(struct config_rotar *crot, int rotchar){
 void free_rotar(struct rotar *rot){
 #ifdef HAVE_HAMLIB
 	if (rot->hl_thread){
-		progress(VTEXT(T_WAIT_HL_ROT_THREAD));		
+		progress(VTEXT(T_WAIT_HL_ROT_THREAD));
 
         rot->hl_thread_break = 1;
         dbg("join hamlib rotar...\n");
@@ -166,12 +177,17 @@ void free_rotar(struct rotar *rot){
         dbg("done\n");
         rot->hl_thread=0;
     }
+
 #endif
-    g_free(rot->desc);
-    g_free(rot->netid);
-    g_free(rot->rem_rotstr);
-    free_sd(rot->sdev);
-    g_free(rot);
+#ifdef OCT8TOR
+	// nothing allocated
+#endif
+	g_free(rot->desc);
+	g_free(rot->netid);
+	g_free(rot->rem_rotstr);
+	free_sd(rot->sdev);
+	g_free(rot);
+
 }
 
 int init_rotars(){
@@ -180,23 +196,53 @@ int init_rotars(){
     int i;
     char rotchar='A';
 
-	progress(VTEXT(T_INIT_ROTARS2));		
+	progress(VTEXT(T_INIT_ROTARS2));
 
     MUTEX_INIT(rotars);
-    rotars=g_ptr_array_new();
+
+	rotars = g_ptr_array_new();
+#ifdef OCT8TOR	
+	goct8tor = init_oct8tor();
+	if (goct8tor != NULL){
+		for (int i = 0; i < cfg->oct_alloc; i++){
+			struct config_rotar octcfg;
+			memset(&octcfg, 0, sizeof(octcfg));
+			octcfg.rot_type = ROT_OCT8TOR;
+			octcfg.rot_poll_ms = 1000;
+			octcfg.rot_desc = g_strdup_printf("Oct%d", i + 1);
+			octcfg.rot_beamwidth = 20;
+			octcfg.rot_offset = 0;
+			octcfg.rot_hostname = cfg->oct_tcp_host;
+			octcfg.rot_port = cfg->oct_remote_tcp_port;
+			octcfg.rot_rem_rotstr = g_strdup_printf("%c", 'A' + i);
+			rot = init_rotar(&octcfg, rotchar++);
+			if (rot){
+				rot->oct_nr = i + 1;
+				MUTEX_LOCK(rotars);
+				g_ptr_array_add(rotars, rot);
+				MUTEX_UNLOCK(rotars);
+			}
+            g_free(octcfg.rot_desc);
+            g_free(octcfg.rot_rem_rotstr);
+		}
+	}
+#endif
+
     for (i=0;i<cfg->crotars->len;i++){
-        cfgrot=(struct config_rotar*)g_ptr_array_index(cfg->crotars, i);
-        if (!cfgrot) continue;
-        rot=init_rotar(cfgrot, rotchar++);
-        if (!rot) continue;
-        MUTEX_LOCK(rotars);
+		cfgrot = (struct config_rotar*)g_ptr_array_index(cfg->crotars, i);
+		if (!cfgrot) continue;
+		rot = init_rotar(cfgrot, rotchar++);
+		if (!rot) continue;
+		MUTEX_LOCK(rotars);
         g_ptr_array_add(rotars, rot); 
         MUTEX_UNLOCK(rotars);
-    }
+	}
+
+
 #ifdef Z_HAVE_SDL
-    rot_update_colors();
+	rot_update_colors();
 #endif
-    return 0;
+	return 0;
 }
 
 int free_rotars(void){
@@ -205,15 +251,20 @@ int free_rotars(void){
 
 	progress(VTEXT(T_INIT_ROTARS2));		
 
+#ifdef OCT8TOR
+	free_oct8tor(goct8tor);
+#endif
+
     MUTEX_LOCK(rotars);
-    for (i=0;i<rotars->len;i++){
-        rot = (struct rotar *) g_ptr_array_index(rotars, i);
+	rotar = NULL;
+	for (i = 0; i<rotars->len; i++){
+		rot = (struct rotar *) g_ptr_array_index(rotars, i);
         free_rotar(rot);
-    }
-    MUTEX_UNLOCK(rotars);
-    g_ptr_array_free(rotars,1);
+	}
+	g_ptr_array_free(rotars,1);
     rotars=NULL;
-    return 0;
+	MUTEX_UNLOCK(rotars);
+	return 0;
 }
 
 #ifdef Z_HAVE_SDL
@@ -257,20 +308,36 @@ int rot_seek(struct rotar *rot, int uhel, int elev){
     if (!rot) return 0;
 
 	int uo = rot_normalize(uhel - rot->offset);
+    
+    TRROT(0, "rot_seek  az=%d  el=%d  (rottype %d)", uo, elev, rot->type);
 
     switch (rot->type){
         case ROT_REMOTE:
-            c = g_strdup_printf("RS %s;%s;%d;%d\n", 
+            if (g_thread_self() == rot->main_thread) {
+                c = g_strdup_printf("RS %s;%s;%d;%d\n",
                     rot->netid, rot->rem_rotstr, uo, elev);
-            rel_write_all(c);
-            g_free(c);
-            
+                rel_write_all(c); // not thread safe
+                g_free(c);
+            }else {
+                c = g_strdup_printf("ROT;%s;SEEK;%d;%d\n", rot->rotstr, uhel, elev);
+                zselect_msg_send(zsel, c);
+                g_free(c);
+            }
             break;
 #ifdef HAVE_HAMLIB            
         case ROT_HAMLIB:
 			rot->hl_azim = uo;
 			rot->hl_elev = elev;
             break;
+#endif
+#ifdef OCT8TOR
+		case ROT_OCT8TOR:
+			//if (!aband) break;
+			MUTEX_LOCK(rotars);
+			rot->oct_azim = uo;
+			rot->oct_elev = elev;
+			MUTEX_UNLOCK(rotars);
+			break;
 #endif
         default:
             job = g_new0(struct sconn_job, 1);
@@ -284,6 +351,52 @@ int rot_seek(struct rotar *rot, int uhel, int elev){
     return 0;
 }
 
+void rotars_stop(){
+	int i;
+	struct rotar *rot = NULL;
+
+	if (!rotars) return;
+	MUTEX_LOCK(rotars);
+	for (i = 0; i<rotars->len; i++){
+		rot = (struct rotar *)g_ptr_array_index(rotars, i);
+		rotar_stop(rot);
+	}
+	MUTEX_UNLOCK(rotars);
+}
+
+void rotar_stop(struct rotar *rot){
+	char *c;
+	//struct sconn_job *job;
+
+	switch (rot->type){
+		case ROT_REMOTE:
+			c = g_strdup_printf("RP %s;%s\n", rot->netid, rot->rem_rotstr);
+			rel_write_all(c);
+			g_free(c);
+
+			break;
+#ifdef HAVE_HAMLIB            
+		case ROT_HAMLIB:
+			rot->hl_stop = 1;
+			break;
+#endif
+#ifdef OCT8TOR
+		case ROT_OCT8TOR:
+			if (!aband) break;
+			MUTEX_LOCK(rotars);
+			rot->oct_stop = 1;
+			MUTEX_UNLOCK(rotars);
+			break;
+#endif
+		default:
+			//job = g_new0(struct sconn_job, 1);  no support
+			//job->cmd = SCONN_ROT_AZIM;
+			//job->sdev = rot->sdev;
+			//sconn_job_add(rot->sdev->sconn, job);
+			break;
+	}
+}
+
 
 struct config_rotar *get_config_rotar_by_number(GPtrArray *crots, int nr){
     struct config_rotar *crot;
@@ -298,11 +411,13 @@ struct config_rotar *get_config_rotar_by_number(GPtrArray *crots, int nr){
 
 struct rotar *get_rotar(int nr){
     struct rotar *rot;
-
-    if (!rotars) return NULL;
-    if (nr>=rotars->len) return NULL;
-
     MUTEX_LOCK(rotars);
+
+    if (!rotars || nr >= rotars->len) {
+        MUTEX_UNLOCK(rotars);
+        return NULL;
+    }
+
     rot = (struct rotar*) g_ptr_array_index(rotars, nr);
     MUTEX_UNLOCK(rotars);
     return rot;
@@ -365,12 +480,23 @@ void rotar_read_handler(int n, char **items){
         log_addf(VTEXT(T_ROTAR_ERROR_S), items[3]);
     }
     if (strcasecmp(cmd, "QTF")==0){
-		char *qtf = items[3];
-		char *elev = items[4];
-		rot->qtf = rot_normalize(atoi(qtf) + rot->offset);
-		rot->elev = atoi(elev);
+		char *qtfstr = g_strdup(items[3]);
+		z_trim_end(qtfstr);
+		if (strlen(qtfstr) > 0){
+			char *qtf = qtfstr;
+			rot->qtf = rot_normalize(atoi(qtf) + rot->offset);
+		}
+		g_free(qtfstr);
+
+		char *elevstr = g_strdup(items[4]);
+		z_trim_end(elevstr);
+		if (strlen(elevstr) > 0){
+			char *elev = elevstr;
+			rot->elev = atoi(elev);
+		}
+		g_free(elevstr);
         
-        zs2 = zconcatesc(gnet->myid, rotstr, qtf, elev, NULL);
+        zs2 = zconcatesc(gnet->myid, rotstr, items[3], items[4], NULL);
         c = g_strconcat("RU ", zs2->str, "\n", NULL);
         rel_write_all(c);
         g_free(c);
@@ -383,13 +509,16 @@ void rotar_read_handler(int n, char **items){
             if (!gses->update_rotar_timer_id)
                 gses->update_rotar_timer_id = zselect_timer_new(zsel, 2*DELAY_AFTER_UPDATE_ROTAR, timer_update_rotar, NULL);
         }
-#endif
-#ifdef Z_HAVE_LIBFTDI
-		hdkeyb_draw_rotar(hdkeyb, rot->rotchar - 'A'); 
 #endif
         redraw_later();
         goto x;
     }
+    if (strcasecmp(cmd, "SEEK") == 0) {
+        int qtf = atoi(items[3]);
+        int ele = atoi(items[4]);
+        rot_seek(rot, qtf, ele);
+    }
+
 x:;	
     redraw_later();
 }
@@ -548,6 +677,8 @@ void rotar_fn(struct dialog_data *dlg)
 }   
 
 void rotar_set_desc(void){
+	if (!rotar) return;
+
     switch(rotar->type){
 #ifdef HAVE_HAMLIB
         case ROT_HAMLIB:
@@ -557,6 +688,11 @@ void rotar_set_desc(void){
         case ROT_REMOTE:
             g_snprintf(rotar_desc1, MAX_STR_LEN, "%s %c (%s %s)", VTEXT(T_ROTAR), rotar->rotchar, rotar->netid, rotar->rem_rotstr);
             break;
+#ifdef OCT8TOR
+		case ROT_OCT8TOR:
+			g_snprintf(rotar_desc1, MAX_STR_LEN, "%s %c (oct8tor %s)", VTEXT(T_ROTAR), rotar->rotchar, rotar->netid);
+			break;
+#endif
         default:
             g_snprintf(rotar_desc1, MAX_STR_LEN, "%s %c (%u)", VTEXT(T_ROTAR), rotar->rotchar, (unsigned char)rotar->sdev->saddr);
             break;
@@ -677,6 +813,12 @@ gpointer rot_hamlib_main(gpointer xxx){
 			rot->hl_azim = -1;
         }
 
+		if (rot->hl_stop){
+			ret = rot_stop(rot->rot);
+			TRROT(1, "rot_stop() = %d", ret);
+			rot->hl_stop = 0;
+		}
+
 		ret = rot_get_position(rot->rot, &azimuth, &elevation);
 		if (ret == RIG_OK){
 			TRROT(1, "rot_get_position() = az %3.1f, el %3.1f", (double)azimuth, (double)elevation);
@@ -727,3 +869,48 @@ int rot_normalize(int az){
 	if (az < 0) az += 360;
 	return az;
 }
+
+#ifdef OCT8TOR
+char rot_get_rotchar_by_oct_nr(int oct_nr){
+
+	MUTEX_LOCK(rotars);
+	for (int i = 0; i<rotars->len; i++){
+		struct rotar *rot = (struct rotar *) g_ptr_array_index(rotars, i);
+		if (rot->oct_nr == oct_nr){
+			MUTEX_UNLOCK(rotars);
+			return rot->rotchar;
+		}
+	}
+	MUTEX_UNLOCK(rotars);
+	return '\0';
+}
+
+// can fail before "rotars" reply
+char rot_get_rotchar_by_ch(const char *ch){
+
+	MUTEX_LOCK(rotars);
+	for (int i = 0; i<rotars->len; i++){
+		struct rotar *rot = (struct rotar *) g_ptr_array_index(rotars, i);
+		if (rot->oct_sys == ch[0]){
+			MUTEX_UNLOCK(rotars);
+			return rot->rotchar;
+		}
+	}
+	MUTEX_UNLOCK(rotars);
+	return '\0';
+}
+
+char rot_get_rotchar_by_sys(const char *sys){
+
+	//MUTEX_LOCK(rotars); called from locked code
+	for (int i = 0; i<rotars->len; i++){
+		struct rotar *rot = (struct rotar *) g_ptr_array_index(rotars, i);
+		if (rot->oct_sys == sys[0]){
+			MUTEX_UNLOCK(rotars);
+			return rot->rotchar;
+		}
+	}
+	//MUTEX_UNLOCK(rotars);
+	return '\0';
+}
+#endif
\ No newline at end of file
