@@ -334,7 +334,7 @@ struct sdr *sdr_start(struct sdr *sdr){
 }
 
 void sdr_stop(struct sdr *sdr){
-	dbg("sdr_stop(%p)\n", sdr);
+	//dbg("sdr_stop(%p)\n", sdr);
 	if (!sdr) return;
 
 	if (sdr->thread){
