@@ -34,7 +34,7 @@ enum modes{ /* TX_RX */
     MOD_CW_SSB,
     MOD_AM_AM,
     MOD_FM_FM,
-    MOD_RTTY_RTTY,
+    MOD_MGM_MGM,
     MOD_SSTV_SSTV,
     MOD_ATV_ATV /* 9 */
 };
