@@ -1671,7 +1671,7 @@ char *stats_valid_key(char *buf, const char *call, const char *wwl, const int ph
 		case MOD_CW_CW:
 			strcpy(buf + strlen(buf), "_CW");
 			break;
-		case MOD_RTTY_RTTY:
+		case MOD_MGM_MGM:
 		case MOD_SSTV_SSTV:
 		case MOD_ATV_ATV:
 			strcpy(buf + strlen(buf), "_DI");
@@ -1705,7 +1705,7 @@ char *stats_valid_key_display(char *buf, const char *call, const char *wwl, cons
 			case MOD_CW_CW:
 				strcpy(buf + strlen(buf), "_CW");
 				break;
-			case MOD_RTTY_RTTY:
+			case MOD_MGM_MGM:
 			case MOD_SSTV_SSTV:
 			case MOD_ATV_ATV:
 				strcpy(buf + strlen(buf), "_DI");
