@@ -58,7 +58,7 @@ int export_all_bands_stf(void){
         "CW",
         "AM",
         "FM",
-        "RTTY",
+        "MGM",
         "SSTV",
         "ATV"
     };
