@@ -72,6 +72,7 @@ struct subwin *new_subwin(enum sw_type type, int where_){
     if (ctest && !ctest->oldcontest) sw->h -= ctest->spypeers->len;
 	sw->cur = -1;
     sw->maxlen = 1000;
+    sw->iconv_handle = (iconv_t)-1;
 
 #ifdef Z_UNIX
     sw->ws.ws_col = sw->w;
@@ -127,7 +128,9 @@ struct subwin *new_subwin(enum sw_type type, int where_){
 
 #ifdef Z_MSC_MINGW
 			sprintf(oemcp, "CP%d", GetOEMCP());
-			sw->iconv = iconv_open("iso-8859-2", oemcp);
+			sw->iconv_handle = iconv_open("iso-8859-2//IGNORE", oemcp);
+            //if (sw->iconv_handle == (iconv_t)-1) zinternal("Can't create iconv object %s to iso-8859-2", oemcp);
+
 #endif
 
 			if (sw->type == SWT_SHELL){
@@ -471,7 +474,7 @@ void free_subwin(struct subwin *sw){
     if (sw->title) g_free(sw->title);
     if (sw->lines) zg_ptr_array_free_all(sw->lines);
     sw_shell_kill(sw);
-	if (sw->iconv) iconv_close(sw->iconv);
+	if (sw->iconv_handle != (iconv_t)-1) iconv_close(sw->iconv_handle);
 	if (sw->sock >= 0){
 		zselect_set(zsel, sw->sock, NULL, NULL, NULL, NULL);
 		closesocket(sw->sock);
@@ -1228,7 +1231,7 @@ int sw_qsos_kbd_func(struct subwin *sw, struct event *ev, int fw){
 		case 'A':
 		case 'a':
 			if (ev->y == 0){
-				sw->allqsos = !sw->allqsos;
+                sw->allqsos = sw->allqsos ? 0 : 1;
 				sw_qsos_check_bounds(sw);
 				redraw_later();
 			}
@@ -1957,12 +1960,12 @@ void sw_shell_read_handler(void *arg){
     *d='\0';
     buf[ret]='\0';
 
-	if (sw->iconv){
+	if (sw->iconv_handle != (iconv_t)-1){
 		size_t a = ret, b = ret;
         pbuf = buf;
         pbuf2 = buf2;
-		iconv(sw->iconv, &pbuf, &a, &pbuf2, &b);
-	    buf2[ret]='\0';
+		iconv(sw->iconv_handle, &pbuf, &a, &pbuf2, &b);
+	    buf2[ret - b]='\0';
 		sw_add_block(sw, buf2);
 	}else{
 		sw_add_block(sw, buf);
