@@ -595,7 +595,7 @@ gpointer trig_main(gpointer xxx){
         return NULL;
     }
 
-    safe_strncpy(trig->rig->state.rigport.pathname, trig->filename, HAMLIB_FILPATHLEN);
+    if (strlen(trig->filename) > 0) safe_strncpy(trig->rig->state.rigport.pathname, trig->filename, HAMLIB_FILPATHLEN); // else keep default
     if (trig->speed > 0) trig->rig->state.rigport.parm.serial.rate = trig->speed;
 	if (trig->handshake_none) trig->rig->state.rigport.parm.serial.handshake = RIG_HANDSHAKE_NONE;
 
