@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2011-2016 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2023 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -31,6 +31,7 @@ struct config_rig{
     int rig_clr_rit;
 	int rig_ptt_t2r;
     int rig_verbose;
+    char *rig_conf;
 };
 
 
@@ -69,6 +70,7 @@ struct trig{
 	int ssbcw_shift;
 	int clr_rit;
 	int ptt_t2r;
+    char* conf;
 
 
 	// state
@@ -134,6 +136,8 @@ void trig_stop_morse(struct trig *trig);
 int trig_save_riglist(const struct rig_caps *caps, void *data);
 int trig_compare (const void *a, const void *b);
 char *trig_short_errstr(enum rig_errcode_e error);
+void trig_set_conf(struct trig* trig);
+
 #endif
 
 
