@@ -223,6 +223,8 @@ struct tsdl *init_sdl(){
         return NULL;
     }
     sdl->bpp = sdl->screen->format->BitsPerPixel;
+    dbg("sdl_init  RMask=%x  GMask=%x  BMask=%x  AMask=%x\n", sdl->screen->format->Rmask, sdl->screen->format->Gmask, sdl->screen->format->Bmask, sdl->screen->format->Amask);
+
     
     ty = sdl->screen->h / 2 - 2 * zsdl->font_h;
 	if (tucnak64){
@@ -296,6 +298,7 @@ void free_sdl(){
 	if (sdl->event_timer_id) zselect_timer_kill(zsel, sdl->event_timer_id);
 #endif
 
+    dbg("free_sdl\n");
     sdl_stop_event_thread();
 	if (sdl->mast) SDL_FreeSurface(sdl->mast);
     if (sdl->icon) SDL_FreeSurface(sdl->icon);
@@ -433,6 +436,7 @@ void sdl_event_timer(void *xxx){
 int sdl_setvideomode(int w, int h, int init_x){
     int i, flags;
     
+    dbg("sdl_setvideomode\n");
     sdl_stop_event_thread();
 
 
@@ -508,11 +512,11 @@ int sdl_setvideomode(int w, int h, int init_x){
 	}
 	
 
-	Uint32 format = SDL_GetWindowPixelFormat(win);
+	sdl->screen = SDL_GetWindowSurface(win);
+	//Uint32 format = SDL_GetWindowPixelFormat(win);
+	Uint32 format = sdl->screen->format->format;
 	SDL_PixelFormat *pxformat = SDL_AllocFormat(format);
 
-	//sdl->screen = SDL_CreateRGBSurface(SDL_SWSURFACE, w, h, pxformat->BitsPerPixel, pxformat->Rmask, pxformat->Gmask, pxformat->Bmask, pxformat->Amask);
-	sdl->screen = SDL_GetWindowSurface(win);
 
 	
 	/*SDL_SetWindowResizable(zsdl->window, SDL_TRUE);
@@ -533,6 +537,7 @@ int sdl_setvideomode(int w, int h, int init_x){
     zsdl->window = win;
     zsdl->format = format;
     zsdl->pxformat = pxformat;
+    dbg("tsdl_init  format=%s  RMask=%x  GMask=%x  BMask=%x  AMask=%x\n", SDL_GetPixelFormatName(zsdl->format), zsdl->pxformat->Rmask, zsdl->pxformat->Gmask, zsdl->pxformat->Bmask, zsdl->pxformat->Amask);
 #endif
 
 
@@ -542,6 +547,7 @@ int sdl_setvideomode(int w, int h, int init_x){
     sdl->termarea.w = w;
     sdl->termarea.h = h;
     
+
     if (sdl->screen->format->palette){
         int i;
         SDL_PixelFormat *fmt;
@@ -568,11 +574,14 @@ int sdl_setvideomode(int w, int h, int init_x){
         fmt->Gloss=5;
         fmt->Bloss=6;
     }
+ //   dbg("tsdl_init  pxformat  RMask=%x  GMask=%x  BMask=%x  AMask=%x\n", zsdl->pxformat->Rmask, zsdl->pxformat->Gmask, zsdl->pxformat->Bmask, zsdl->pxformat->Amask);
+    //dbg("tsdl_init  scrforma  RMask=%x  GMask=%x  BMask=%x  AMask=%x\n", zsdl->screen->format->Rmask, zsdl->screen->format->Gmask, zsdl->screen->format->Bmask, zsdl->screen->format->Amask);
     pal[0].r = pal[0].g = pal[0].b = 0;
     sdl->gr[0] = z_makecol(0, 0, 0);
     for (i=1; i<16; i++){
         pal[i].r = pal[i].g = pal[i].b = i*4+3;
         sdl->gr[i] = z_makecol(i*16+15, i*16+15, i*16+15);
+        //dbg("gr[%d] = %x\n", i, sdl->gr[i]);
     }
     for (i=0; i<16; i++){
         int r,g,b;
@@ -1081,11 +1090,11 @@ gpointer sdl_event_thread(gpointer handle){
 #endif
 		case SDL_KEYDOWN:
 			strcpy(type, "KEYDOWN");
-#if 0
 			//if (sev.key.keysym.sym != SDLK_LCTRL && sev.key.keysym.sym != SDLK_RCTRL && sev.key.keysym.sym != SDLK_LALT && sev.key.keysym.sym != SDLK_RALT && sev.key.keysym.sym != SDLK_LSHIFT && sev.key.keysym.sym != SDLK_RSHIFT)
-			if (sev.key.keysym.scancode != SDL_SCANCODE_LCTRL)
-				dbg("KEYDOWN: scan=%d sym=%d '%c' mod=%d (%s)   GetMods=(%s)\n", sev.key.keysym.scancode, sev.key.keysym.sym, sev.key.keysym.sym, sev.key.keysym.mod, dumpmods(&sev.key.keysym), dumpmods(NULL));
-#endif                
+            if (cfg->trace_keys) {
+                if (sev.key.keysym.scancode != SDL_SCANCODE_LCTRL)
+                    dbg("KEYDOWN: scan=%d sym=%d '%c' mod=%d (%s)   GetMods=(%s)\n", sev.key.keysym.scancode, sev.key.keysym.sym, sev.key.keysym.sym, sev.key.keysym.mod, dumpmods(&sev.key.keysym), dumpmods(NULL));
+            }
 
 			if (cfg->altsyms){
 				oldaltsym = sdl->altsym;
@@ -1424,6 +1433,12 @@ gpointer sdl_event_thread(gpointer handle){
                 ev.x='q';
                 ev.y=KBD_ALT;
                 goto send;
+            case SDL_APP_WILLENTERBACKGROUND:
+                sdl->paused = 1;
+                break;
+            case SDL_APP_DIDENTERFOREGROUND:
+                sdl->paused = 0;
+                break;
         }
         continue;
 sendkeydown:        
@@ -1450,8 +1465,10 @@ sendkeydown:
             }
         }
 #ifdef Z_HAVE_SDL2
-		//dbg("(%s) EV_KBD %d '%c' %s %s %s\n\n", sev.type == SDL_TEXTINPUT ? "TEXTINPUT" : (sev.type == SDL_KEYDOWN ? "KEYDOWN" : "?"), 
-		//	ev.x, ev.x, ev.y & KBD_SHIFT ? "SHIFT" : "", ev.y & KBD_CTRL ? "CTRL" : "", ev.y & KBD_ALT ? "ALT" : "");
+        if (cfg->trace_keys) {
+            dbg("(%s) EV_KBD %d '%c' %s %s %s\n\n", sev.type == SDL_TEXTINPUT ? "TEXTINPUT" : (sev.type == SDL_KEYDOWN ? "KEYDOWN" : "?"),
+                ev.x, ev.x, ev.y & KBD_SHIFT ? "SHIFT" : "", ev.y & KBD_CTRL ? "CTRL" : "", ev.y & KBD_ALT ? "ALT" : "");
+        }
 #endif
 
 		goto send;
@@ -1658,6 +1675,8 @@ void progress(char *m, ...){
 	int x, y, yy, w, h, tw;
 
 	if (!sdl) return;
+    if (sdl->paused) return;
+
 	if (!zsdl) return;
 	if (!m) {
 		if (term) memset(term->last_screen, 0, term->x * term->y * sizeof(unsigned));
