@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -48,7 +48,12 @@ void free_wizz_item(struct wizz_item *wi){
     if (wi->pexch) g_free(wi->pexch);
     if (wi->excname) g_free(wi->excname);
     if (wi->bands) g_free(wi->bands);
-    
+    for (struct wizz_qsomult_item *wqi = wi->qsomults; wqi != NULL; ){
+        struct wizz_qsomult_item *tmp = wqi;
+        wqi = wqi->next;
+        g_free(tmp);
+    }
+
     g_free(wi);
 }
 
