@@ -504,25 +504,43 @@ int zosk_send(struct zosk *zosk){
 	int i;
 	struct zosk_key *key = zosk->sent;
 
+	SDL_Keycode sym = key->sym;
+	if (zosk->fn->pressed && key->symFn != SDLK_UNKNOWN) sym = key->symFn;
+	if (zosk->shift->pressed && key->symShift != SDLK_UNKNOWN) sym = key->symShift;
+
 	memset(&ev, 0, sizeof(ev));
-	ev.type = SDL_KEYDOWN;
-	ev.key.keysym.mod = KMOD_NONE;
-	if (zosk->ctrl->pressed) ev.key.keysym.mod = KMOD_LCTRL;
-    if (zosk->alt->pressed) ev.key.keysym.mod = KMOD_LALT;
-    if (zosk->shift->pressed) ev.key.keysym.mod = KMOD_LSHIFT;
-	ev.key.keysym.scancode = 1;
-	ev.key.keysym.sym = key->sym;
-	if (zosk->fn->pressed && key->symFn != SDLK_UNKNOWN) ev.key.keysym.sym = key->symFn;
-	if (zosk->shift->pressed && key->symShift != SDLK_UNKNOWN) ev.key.keysym.sym = key->symShift;
-#ifdef Z_HAVE_SDL1
-	ev.key.keysym.unicode = 0;
-	ev.key.which = 0;
+#ifdef Z_HAVE_SDL2
+	if (key->sym >= SDLK_SPACE && !zosk->ctrl->pressed && !zosk->alt->pressed) {
+		ev.type = SDL_TEXTINPUT;
+		ev.text.timestamp = SDL_GetTicks();
+		if (zosk->shift->pressed && key->symShift == SDLK_UNKNOWN) sym = toupper(sym);
+        if (zosk->flags & ZOSK_UPCONVERT) sym = toupper(sym);
+		g_snprintf(ev.text.text, SDL_TEXTINPUTEVENT_TEXT_SIZE, "%c", sym);
+	}
+	else
 #endif
-	ev.key.state = SDL_PRESSED;
+	{
+		ev.type = SDL_KEYDOWN;
+		ev.key.keysym.mod = KMOD_NONE;
+		if (zosk->ctrl->pressed) ev.key.keysym.mod = KMOD_LCTRL;
+		if (zosk->alt->pressed) ev.key.keysym.mod = KMOD_LALT;
+		if (zosk->shift->pressed) ev.key.keysym.mod = KMOD_LSHIFT;
+		ev.key.keysym.scancode = 1;
+		ev.key.keysym.sym = sym;
+		ev.key.state = SDL_PRESSED;
+#ifdef Z_HAVE_SDL1
+		ev.key.keysym.unicode = 0;
+		ev.key.which = 0;
+#endif
+	}
 	SDL_PushEvent(&ev);
     //dbg("push %d\n", ev.key.keysym.sym);
 
-	if (!zosk->ctrl->pressed && !zosk->alt->pressed){
+	if (!zosk->ctrl->pressed && !zosk->alt->pressed && ev.type == SDL_TEXTINPUT){
+        g_string_append(zosk->gs, ev.text.text);
+    }
+
+	if (!zosk->ctrl->pressed && !zosk->alt->pressed && ev.type == SDL_KEYDOWN){
 		if (ev.key.keysym.sym >= ' ' && ev.key.keysym.sym < 128){
 			if (zosk->shift->pressed || (zosk->flags & ZOSK_UPCONVERT))
 				g_string_append_c(zosk->gs, z_char_uc((char)ev.key.keysym.sym));
