@@ -13,16 +13,17 @@
 
 #include "tsdl.h"
 
+
 #ifdef Z_HAVE_SDL
 struct zosk_key{
     int x, y, w, h, cx, cy;
 	int isshift, pressed;
-    SDLKey sym, symFn, symShift;
+	SDL_Keycode sym, symFn, symShift;
     char text[5], textFn[5], textShift[5];
 };
 
 struct zosk{
-    SDL_Surface *surface;
+	SDL_Surface *surface;
     GPtrArray *keys;
     int bw2, bh, x0, y0, x2, y;
     int KX2, KY;
